<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="ja_JP">
<defaultcodec>ISO-8859-5</defaultcodec>
<context>
    <name>@default</name>
    <message>
        <location filename="ThemeClockDraw.cpp" line="29"/>
        <source>Drop theme file in this form.</source>
        <translation type="obsolete">テーマファイルを、このフォームにドロップして下さい。</translation>
    </message>
    <message>
        <location filename="ThemeClockWidget.cpp" line="118"/>
        <source>E&amp;xit</source>
        <translation type="obsolete">終了&amp;x</translation>
    </message>
    <message>
        <location filename="ThemeClockWidget.cpp" line="126"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl-Q</translation>
    </message>
</context>
<context>
    <name>QAction</name>
    <message>
        <location filename="ThemeClockWidget.cpp" line="125"/>
        <source>E&amp;xit</source>
        <translation>終了(&amp;x)</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <location filename="ThemeClockDraw.cpp" line="126"/>
        <source>Drop theme file in this form.</source>
        <translation>テーマファイルを、このフォームにドロップして下さい。</translation>
    </message>
</context>
<context>
    <name>ThemeClockWidget</name>
    <message>
        <location filename="ThemeClockWidget.cpp" line="245"/>
        <source>qtmclock</source>
        <translation>qtmclock</translation>
    </message>
    <message>
        <location filename="ThemeClockWidget.cpp" line="246"/>
        <source>%1 is not correct theme file.</source>
        <translation>%1 はテーマファイルではありません。</translation>
    </message>
</context>
</TS>
